.float doggie;
void () s_explode1 = [0, s_explode2] {};
void () s_explode2 = [1, s_explode3] {};
void () s_explode3 = [2, s_explode4] {};
void () s_explode4 = [3, s_explode5] {};
void () s_explode5 = [4, s_explode6] {};
void () s_explode6 = [5, SUB_Remove] {};


//=============================================================================
// Blaze Gun
//
// 11/21/96 by Jonathan E. Wright <nelno@interpath.com>
//
// all original code, not based on anything except the original Quake C
// code from id software.
//=============================================================================

// How it works:
// The flame is simply your basic flame model turned 90 degress on it's side
// when it is shot.  When it impacts something that has health > 0 and DAMAGE_AIM
// it sets it's location to that entity's origin, and it's next think becomes
// blaze_stick.  blaze_stick is responsible for following the burning entity,
// checking for water, determining if there is another entity nearby to burn
// and burning the entity every so often.  The time counter for each burn is kept
// in the flame's attack_finished field, so the entity does not have to be burnt
// each time the flame follows it.  When the entity dies, or the flame is submersed
// in water the flame is removed and no more damage is done from that flame.  This
// is all accomplished without adding any extra fields to the entity.

/*
================
macros
================
*/
$frame nailatt1 nailatt2

/*
================
function prototypes
================
*/

// void () player_run;
// void () BecomeExplosion;
// void () SuperDamageSound;

/*
================
global vars
================
*/

// keeps track of the number of flames so that a maximum of flames
// will not be exceeded, causing Quake to bog down

float   current_flames;

/*
============
functions
============
*/


/*
===============
blaze_spread

called by blaze_stick.

creates a new flame entity which will stick to and burn entity "fuel"
===============
*/

void () blaze_stick;

void (entity fuel) blaze_spread =
{
  local   entity   new_flame;

  // don't catch the same entity on fire again!
  // don't catch anything that can't take damage
  if ((fuel.takedamage != DAMAGE_AIM) || (current_flames >= 30))
  {
     return;
  }
  else if ((fuel.classname == "player") && (random () > 0.75))
  {
    return;
  }
  else if (random () > 0.5)
  {
    return;
  }

  current_flames = current_flames + 1;



  if (fuel.classname == "player")
  {
sound ( fuel, CHAN_VOICE, "burnme.wav", 1.00000, ATTN_NORM);

    bprint (fuel.netname);
    bprint (" is on fire!!\n");
  }
  else if (fuel.classname == "cujo")
    sprint (fuel.owner, "Your dog is aflame!!\n");

  new_flame = spawn ();

  // set the sucker on fire!
  new_flame.enemy = fuel;
  new_flame.solid = SOLID_NOT;
  new_flame.angles_x = 0;

 // new_flame.movetype = fuel.movetype;
  new_flame.movetype = MOVETYPE_TOSS;
  new_flame.effects = EF_DIMLIGHT;
  new_flame.takedamage = DAMAGE_NO;
  new_flame.classname = "fire";
  new_flame.targetname = "";
new_flame.owner = self.owner;
  new_flame.think = blaze_stick;
  new_flame.nextthink = time;

  // always points back to the player who fired the original flame
  // so monsters get mad at player, not at flames!
  new_flame.owner = self.owner;

  setmodel (new_flame, "models/flameC.mdl");
  setsize (new_flame, '2 2 2', '2 2 2');
if (fuel.flags2 & FL_ALIVE ) {
  setorigin (new_flame, fuel.origin);
} else {
setorigin (new_flame, self.origin);
}
};

/*
===============
blaze_findfuel

called by blaze_stick

searches for the closest entity within a certain radius.  If a qualifying entity is
found, and a random chance met, the entity is caught on fire by calling blaze_spread.

Notice there is a greater chance for players to be caught on fire, since they tend to
move around quite a bit more than monsters, and are less likely to remain near a flame
===============
*/

void (float dist) blaze_findfuel =
{
  local   entity   head;
  local   entity   fuel;
  local   float    lastd;

  // anything dist units away can catch flame
  head = findradius (self.origin, dist);
  fuel = world;

  while (head)
  {
    if ((head != self.enemy) && (head.takedamage == DAMAGE_AIM))
    {
      // find the distance to the current entity, so we can choose the closest
      // entity within the radius
      lastd = vlen (self.origin - head.origin);
      if (lastd < dist)
      {
        fuel = head;
        dist = lastd;
      }
    }
    head = head.chain;
  }

  if ((fuel != world) && (random () < 0.1))
  {
sound ( self, CHAN_VOICE, "burnme.wav", 1.00000, ATTN_NORM);
    blaze_spread (fuel);
  }
};

/*
===============
blaze_stick

called every frame as the flame's think function.  responsible for control
the flame once it has attached to an entity -- not in flight from the blaze gun!

checks for water submersion each frame
===============
*/

void () burn_entity;

void () blaze_stick =
{
  local   vector   org;
  local   vector   fuelsize, xv, yv, zv;
  local   float    pc;
  local   float    average_width;
  
self.burn = (self.burn - 0.01);
 if (self.burn < 0.9) {
remove (self);
return;
 }

  pc = pointcontents (self.origin);
  if ((pc == CONTENT_WATER) || (pc == CONTENT_SLIME))
  {
    // water extinguished the flame
    sound (self, CHAN_WEAPON, "blaze/flhiss1.wav", 1, ATTN_NORM);
    // reset inflictor so enities don't keep going for water
    // self.enemy.dmg_inflictor = self.enemy;
    current_flames = current_flames - 1;
    remove (self);
    return;
  }

  fuelsize = self.enemy.size;
// BAER NEW CODE
	self.scale = random(0.75, 2.50);
// BAER end of code
  // it's really the average of x_width and y_width * 2;
  average_width = (fuelsize_x + fuelsize_y) * 0.5;
  blaze_findfuel (average_width);

  // make the flames dance, baby! dance!

  if (self.enemy.classname == "monster_shambler")
    pc = 0.5;
  else
    pc = 0.2;

  fuelsize_x = fuelsize_x * pc * random ();
  if (random () < 0.5)
    fuelsize_x = fuelsize_x * -1;
  fuelsize_y = fuelsize_y * pc * random ();
  if (random () < 0.5)
    fuelsize_y = fuelsize_y * -1;
  fuelsize_z = fuelsize_z * pc * random ();
  if ((random () < 0.5) && (self.enemy.classname != "monster_shambler"))
    fuelsize_z = fuelsize_z * -1;
if (self.enemy.flags2 & FL_ALIVE) {
  org = self.enemy.origin + fuelsize;
} else { 
  org = self.origin + fuelsize;
}
if (self.enemy.thingtype & THINGTYPE_WOOD) {
  org = self.enemy.origin + fuelsize;
}
  setorigin (self, org);

if (self.owner.owner.classname == "balloffirefrag") {
T_RadiusDamage (self, self.owner, 11, world);
}
  if (self.velocity == '0 0 0') self.avelocity = '0 0 0';
  particle2 ( self.origin, '-30.00000 -30.00000 50.00000', '30.00000 30.00000 100.00000', 140.00000, 16, 10.00000);
self.think = blaze_stick;
  self.nextthink = time;

  // targetname is used as a flag here to determine if the entity
  // has already been determined to be deadm and the attack_finished time
  // already increased -- without the flag, the flames won't burn out
  // because the attack_finished time will always be increasing
if ((self.enemy.health<5) && (self.enemy.doggie == 0)) {
if (self.enemy.classname == "monster_archer") {
sound ( self, CHAN_VOICE, "burnme.wav", 1.00000, ATTN_NORM);
self.enemy.doggie = 1;
}
if (self.enemy.classname == "monster_archer_lord") {
sound ( self, CHAN_VOICE, "burnme.wav", 1.00000, ATTN_NORM);
self.enemy.doggie = 1;
}
if (self.enemy.classname == "monster_mezzoman") {
sound ( self, CHAN_VOICE, "burnme.wav", 1.00000, ATTN_NORM);
self.enemy.doggie = 1;
}
if (self.enemy.classname == "monster_werepanther") {
sound ( self, CHAN_VOICE, "burnme.wav", 1.00000, ATTN_NORM);
self.enemy.doggie = 1;
}
if (self.enemy.classname == "player") {
sound ( self, CHAN_VOICE, "burnme.wav", 1.00000, ATTN_NORM);
self.enemy.doggie = 1;
}

}


  if ((self.enemy.health <= 0) && (self.targetname == "") &&
       (self.enemy.classname != "monster_zombie"))
  {
    self.attack_finished = 7 * random () + time;
    self.targetname = "already_dead";
//    bprint (self.enemy.classname);
//    bprint (" is dead and burning\n");
  }

  if (self.attack_finished <= time) burn_entity ();
};

/*
===============
burn_entity -- called by the flame

called each time attack_finished <= time, currently every second
responsible for damaging the entity the flame is attached to

zombies are a special case and recieve quite a bit more damage than
a normal monster or player so that a few flames and sometimes a single
flame, can gib them
===============
*/

void () burn_entity =
{
  if (self.enemy.health <= 0)
  {
    current_flames = current_flames - 1;
    remove (self);
    return;
  }
// burn - 0.01; 
 if (self.enemy.classname != "monster_zombie")
    T_Damage (self.enemy, self, self.owner, 6 * random () + 1);
  else
    T_Damage (self.enemy, self, self.owner, 50 * random () + 10);

  if (self.enemy.classname == "player")
    centerprint (self.enemy, "You're on fire!\nFind some water!");

  self.think = blaze_stick;
  self.nextthink = time;
  self.attack_finished = time + 1;
};

/*
===============
blaze_watercheck

called as the flame's thin function from the time it is fired until it hits
and is removed or catches and entity on fire
===============
*/

void() blaze_watercheck =
{
  local float  pc;

  pc = pointcontents (self.origin);
  if ((pc == CONTENT_WATER) || (pc == CONTENT_SLIME) || (self.attack_finished <= time))
  {
    sound (self, CHAN_WEAPON, "blaze/flhiss1.wav", 1, ATTN_NORM);
    // reset inflictor so enities don't keep going for water
    remove (self);

    // make the little grey particles
    WriteByte (MSG_BROADCAST, SVC_TEMPENTITY);
    WriteByte (MSG_BROADCAST, TE_GUNSHOT);
    WriteCoord (MSG_BROADCAST, self.origin_x);
    WriteCoord (MSG_BROADCAST, self.origin_y);
    WriteCoord (MSG_BROADCAST, self.origin_z);

    return;
  }

  self.think = blaze_watercheck;
  self.nextthink = time;
};

/*
===============
blaze_touch

the touch function of an in-flight flame.  responsible for setting an
entity aflame when it hits it (if the random chance is met)
===============
*/

void() blaze_touch =
{
local float nap;
  local vector org;
 local float  pc;

nap = random(0.00000,2.00000);

  pc = pointcontents (self.origin);
  if ((pc == CONTENT_SKY) || (pc == CONTENT_WATER) || (pc == CONTENT_SLIME))
  {
    remove (self);
    return;
  }
  

  // sound (self, CHAN_WEAPON, "blaze/flhit1.wav", 1, ATTN_NORM);

  org = self.origin - 8*normalize(self.velocity);

  if ((other.health) && (other.takedamage == DAMAGE_AIM))
    T_Damage (other, self, self.owner, 15);
  else
  {
    // makes a little debris appear for one frame
    WriteByte (MSG_BROADCAST, SVC_TEMPENTITY);
    WriteByte (MSG_BROADCAST, TE_GUNSHOT);
    WriteCoord (MSG_BROADCAST, org_x);
    WriteCoord (MSG_BROADCAST, org_y);
    WriteCoord (MSG_BROADCAST, org_z);
	CreateWhiteSmoke(self.origin, '0 0 10', HX_FRAME_TIME * 3); // BAER added this
  }

  // does some radius damage, < 1/3 that of a rocket
  T_RadiusDamage (other, self.owner, 35, self);

//  if ((other.health) && (other.takedamage == DAMAGE_AIM))
 // {
    if (nap < 0.6) {
    if ( (other.thingtype != THINGTYPE_GREYSTONE) ) {
      if ( (other.thingtype != THINGTYPE_METAL) ) {

if (self.enemy.classname == "monster_archer") {
self.enemy.doggie = 1;
}
if (self.enemy.classname == "monster_archer_lord") {
self.enemy.doggie = 1;
}
if (self.enemy.classname == "monster_mezzoman") {
self.enemy.doggie = 1;
}
if (self.enemy.classname == "monster_werepanther") {
self.enemy.doggie = 1;
}
if (self.enemy.classname == "player") {
self.enemy.doggie = 1;
}



      // set the sucker on fire!
       self.enemy = other;
     self.burn = random(3.00000,10.00000); 
     self.solid = SOLID_NOT;
 //     self.movetype = self.enemy.movetype;
     self.movetype = MOVETYPE_TOSS; 
if (self.enemy != world) {     
self.origin = self.enemy.origin;
} else {
setorigin(self, self.origin);
}
      self.think = blaze_stick;
      self.nextthink = time + 0.2;
      self.attack_finished = time + 1;
//      self.classname = "fire";
//      self.targetname = "";
      // point flame upright
      self.angles_x = 0;

      current_flames = current_flames + 1;

      return;
    }
  }
}
 // BecomeExplosion ();
T_Damage (other, self, self.owner, 7);
 remove (self);
};
